@@ -191,7 +191,7 @@ pub mod macros {
     }
     /// vec_element_parse!() can be used to
     /// parse vec item to f64,
-    /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>,
+    /// type can be Vec\<&str\>
     /// return Vec\<f64\>
     /// ```rust
     ///let v1 = vec_element_parse!(vec!["15.", "2.9"]);
@@ -382,7 +382,6 @@ pub mod macros {
                     if v1[i - 1] == *target {
                         v1.remove(i - 1);
                     }
-                    // dbg!(&i);
                 }
                 if v1[v1.len() - 1] == *target {
                     v1.remove(v1.len() - 1);
@@ -392,7 +391,80 @@ pub mod macros {
             remove(vec, &$element)
         };};
     }
-    pub fn run() {}
+    /// slice_vec!() used to
+    /// slice vec by range
+    /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>,Vec\<&str\>
+    /// return return the same type
+    /// ```rust
+    ///let v1 = slice_vec!(vec![1.2, 1.5, 9.0], [..2]);
+    ///let v2 = slice_vec!(vec![1, 1, 9, 90, 87, 0, 2], [4..6]);
+    ///let v3 = slice_vec!(vec![1.2, 1.5, 9.0], [..]);
+    ///let v4 = slice_vec!(vec![1.2, 1.5, 9.0], [1..]);
+    ///let v5 = slice_vec!(vec!["1", "2", "3", "4", "5"], [2..5]);
+    ///assert_eq!(v1, vec![1.2, 1.5]);
+    ///assert_eq!(v2, vec![87, 0]);
+    ///assert_eq!(v3, vec![1.2, 1.5, 9.0]);
+    ///assert_eq!(v4, vec![1.5, 9.0]);
+    ///assert_eq!(v5, vec!["3", "4", "5"]);
+    /// ```
+    #[macro_export]
+    macro_rules! slice_vec {
+        ($vec:expr,$slice:expr) => {{
+            let mut vec = $vec.clone();
+            let slice = $slice.clone();
+            fn slice_func<T: Copy>(vec: Vec<T>, start: usize, stop: usize) -> Vec<T> {
+                let mut re = vec![];
+                for (index, item) in vec.iter().enumerate() {
+                    if index >= start && index < stop {
+                        re.push(item.to_owned());
+                    }
+                }
+                re
+            }
+            let s = format!("{:?}", slice);
+            let mut start = 0;
+            let mut stop = vec.len();
+            let s_vec1 = split_to_vec!(s, "[");
+            let s_vec2 = split_to_vec!(s_vec1[0], "]");
+            let s_vec22: Vec<char> = s_vec2[0].chars().collect();
+            let s_vec3 = split_to_vec!(s_vec2[0], "..");
+            let s_vec4 = vec_element_parse!(s_vec3);
+            let mut left = false;
+            let mut right = false;
+            if s_vec22.len() == 3 {
+                if s_vec22[0] == '.' {
+                    left = true;
+                } else if s_vec22[2] == '.' {
+                    right = true;
+                }
+            }
+            if left == false && right == false {
+                if s_vec4.len() > 1 {
+                    start = s_vec4[0] as usize;
+                    stop = s_vec4[1] as usize;
+                } else {
+                    stop = vec.len();
+                }
+            } else if left == true {
+                stop = s_vec4[0] as usize;
+            } else if right == true {
+                start = s_vec4[0] as usize;
+            }
+            slice_func(vec, start, stop)
+        };};
+    }
+    pub fn run() {
+        let v1 = slice_vec!(vec![1.2, 1.5, 9.0], [..2]);
+        let v2 = slice_vec!(vec![1, 1, 9, 90, 87, 0, 2], [4..6]);
+        let v3 = slice_vec!(vec![1.2, 1.5, 9.0], [..]);
+        let v4 = slice_vec!(vec![1.2, 1.5, 9.0], [1..]);
+        let v5 = slice_vec!(vec!["1", "2", "3", "4", "5"], [2..5]);
+        assert_eq!(v1, vec![1.2, 1.5]);
+        assert_eq!(v2, vec![87, 0]);
+        assert_eq!(v3, vec![1.2, 1.5, 9.0]);
+        assert_eq!(v4, vec![1.5, 9.0]);
+        assert_eq!(v5, vec!["3", "4", "5"]);
+    }
 }
 
 #[cfg(test)]
